==> spire-1.3.3.tar.gz: spire-1.3.3/pkg/server/plugin/upstreamauthority/awspca/pca_client_fake.go <==
package awspca

import (
	"testing"

	"github.com/aws/aws-sdk-go/aws"
	"github.com/aws/aws-sdk-go/aws/request"
	"github.com/aws/aws-sdk-go/service/acmpca"
	"github.com/stretchr/testify/require"
)

type pcaClientFake struct {
	t testing.TB

	describeCertificateOutput *acmpca.DescribeCertificateAuthorityOutput
	expectedDescribeInput     *acmpca.DescribeCertificateAuthorityInput
	describeCertificateErr    error

	issueCertificateOutput *acmpca.IssueCertificateOutput
	expectedIssueInput     *acmpca.IssueCertificateInput
	issueCertifcateErr     error

	expectedGetCertificateInput *acmpca.GetCertificateInput
	getCertificateOutput        *acmpca.GetCertificateOutput
	getCertificateErr           error

	waitUntilCertificateIssuedErr error
}

func (f *pcaClientFake) DescribeCertificateAuthorityWithContext(ctx aws.Context, input *acmpca.DescribeCertificateAuthorityInput, option ...request.Option) (*acmpca.DescribeCertificateAuthorityOutput, error) {
	require.Equal(f.t, f.expectedDescribeInput, input)
	if f.describeCertificateErr != nil {
		return nil, f.describeCertificateErr
	}
	return f.describeCertificateOutput, nil
}

func (f *pcaClientFake) IssueCertificateWithContext(ctx aws.Context, input *acmpca.IssueCertificateInput, option ...request.Option) (*acmpca.IssueCertificateOutput, error) {
	require.Equal(f.t, f.expectedIssueInput, input)
	if f.issueCertifcateErr != nil {
		return nil, f.issueCertifcateErr
	}
	return f.issueCertificateOutput, nil
}

func (f *pcaClientFake) WaitUntilCertificateIssuedWithContext(ctx aws.Context, input *acmpca.GetCertificateInput, option ...request.WaiterOption) error {
	require.Equal(f.t, f.expectedGetCertificateInput, input)

	return f.waitUntilCertificateIssuedErr
}

func (f *pcaClientFake) GetCertificateWithContext(ctx aws.Context, input *acmpca.GetCertificateInput, option ...request.Option) (*acmpca.GetCertificateOutput, error) {
	require.Equal(f.t, f.expectedGetCertificateInput, input)
	if f.getCertificateErr != nil {
		return nil, f.getCertificateErr
	}
	return f.getCertificateOutput, nil
}

==> spire_1.7.2.orig.tar.gz: spire-1.7.2/pkg/server/plugin/upstreamauthority/awspca/pca_client_fake.go <==
package awspca

import (
	"context"
	"testing"

	"github.com/aws/aws-sdk-go-v2/service/acmpca"
	"github.com/stretchr/testify/require"
)

type pcaClientFake struct {
	t testing.TB

	describeCertificateOutput *acmpca.DescribeCertificateAuthorityOutput
	expectedDescribeInput     *acmpca.DescribeCertificateAuthorityInput
	describeCertificateErr    error

	issueCertificateOutput *acmpca.IssueCertificateOutput
	expectedIssueInput     *acmpca.IssueCertificateInput
	issueCertifcateErr     error

	expectedGetCertificateInput *acmpca.GetCertificateInput
	getCertificateOutput        *acmpca.GetCertificateOutput
	getCertificateErr           error
}

func (f *pcaClientFake) DescribeCertificateAuthority(_ context.Context, input *acmpca.DescribeCertificateAuthorityInput, _ ...func(*acmpca.Options)) (*acmpca.DescribeCertificateAuthorityOutput, error) {
	require.Equal(f.t, f.expectedDescribeInput, input)
	if f.describeCertificateErr != nil {
		return nil, f.describeCertificateErr
	}
	return f.describeCertificateOutput, nil
}

func (f *pcaClientFake) IssueCertificate(_ context.Context, input *acmpca.IssueCertificateInput, _ ...func(*acmpca.Options)) (*acmpca.IssueCertificateOutput, error) {
	require.Equal(f.t, f.expectedIssueInput, input)
	if f.issueCertifcateErr != nil {
		return nil, f.issueCertifcateErr
	}
	return f.issueCertificateOutput, nil
}

func (f *pcaClientFake) GetCertificate(_ context.Context, input *acmpca.GetCertificateInput, _ ...func(*acmpca.Options)) (*acmpca.GetCertificateOutput, error) {
	require.Equal(f.t, f.expectedGetCertificateInput, input)
	if f.getCertificateErr != nil {
		return nil, f.getCertificateErr
	}
	return f.getCertificateOutput, nil
}
